import { Attribute, DataSource, Filter, FilterRelations, Measure } from '@sisense/sdk-data';
import { GetNlgInsightsRequest } from './api/types';
import { GetNlgInsightsProps } from './get-nlg-insights';
/**
 * Parameters for {@link useGetNlgInsights} hook.
 */
export interface UseGetNlgInsightsParams {
    /** The data source that the query targets - e.g. `Sample ECommerce` */
    dataSource: DataSource;
    /** Dimensions of the query */
    dimensions?: Attribute[];
    /** Measures of the query */
    measures?: Measure[];
    /** Filters of the query */
    filters?: Filter[] | FilterRelations;
    /**
     * Boolean flag to enable/disable API call by default
     *
     * If not specified, the default value is `true`
     */
    enabled?: boolean;
    /** The verbosity of the NLG summarization */
    verbosity?: 'Low' | 'High';
}
/**
 * State for {@link useGetNlgInsights} hook.
 */
export interface UseGetNlgInsightsState {
    /** Whether the data fetching is loading */
    isLoading: boolean;
    /** Whether the data fetching has failed */
    isError: boolean;
    /** Whether the data fetching has succeeded */
    isSuccess: boolean;
    /** The result data */
    data: string | undefined;
    /** The error if any occurred */
    error: unknown;
    /** Callback to trigger a refetch of the data */
    refetch: () => void;
}
/** @internal */
export declare function prepareGetNlgInsightsPayload(params: UseGetNlgInsightsParams | GetNlgInsightsRequest): GetNlgInsightsRequest;
/**
 *
 * @param params - {@link UseGetNlgInsightsParams}
 * @param enabled - boolean flag to enable/disable this hook
 * @internal
 */
export declare const useGetNlgInsightsInternal: (params: GetNlgInsightsProps | GetNlgInsightsRequest, enabled?: boolean) => UseGetNlgInsightsState;
/**
 * React hook that fetches an analysis of the provided query using natural language generation (NLG).
 * Specifying a query is similar to providing parameters to a {@link useExecuteQuery} hook, using dimensions, measures, and filters.
 *
 * @example
 * ```tsx
 * const { data, isLoading } = useGetNlgInsights({
 *   dataSource: 'Sample ECommerce',
 *   dimensions: [DM.Commerce.Date.Years],
 *   measures: [measureFactory.sum(DM.Commerce.Revenue)],
 * });
 *
 * if (isLoading) {
 *   return <div>Loading...</div>;
 * }
 *
 * return <p>{data}</p>;
 * ```
 * @returns Response object containing a text summary
 * @group Generative AI
 */
export declare const useGetNlgInsights: (params: UseGetNlgInsightsParams) => UseGetNlgInsightsState;
