import { type Filter } from '@sisense/sdk-data';
import { WidgetProps } from '../../props.js';
import { OpenMenuFn } from '../../common/components/menu/types.js';
import { DataPoint } from '../../types';
import { WidgetsOptions } from '../../index-typedoc';
import { JTDConfig, JTDDrillTarget } from '../../widget-by-id/types';
import React from 'react';
import { SizeMeasurement } from '../../types';
/**
 * Jump to Dashboard (JTD) Filter Merging Logic:
 *
 * When a user clicks on a datapoint to open a JTD modal, multiple types of filters are merged:
 *
 * 1. **Generated Filters**: Created from the clicked datapoint's category and breakBy entries
 * 2. **Dashboard Filters**: Current dashboard filters (filtered by includeDashFilterDims)
 * 3. **Widget Filters**: Original widget-specific filters (filtered by includeWidgetFilterDims)
 * 4. **Formula Context Filters**: NEW - Embedded filters from the clicked widget's datapoint calculations
 *
 * ## Formula Context Filters (New Feature)
 *
 * Formula context filters are embedded within datapoint calculations and represent intrinsic
 * filters that are part of the measure/column computation itself. They are extracted only from
 * the specific widget that was clicked, not from all widgets. For example:
 *
 * ```
 * clickedWidget.dataOptions.value[0].column.context = {
 *   "13FC1-655": {
 *     "type": "filter",
 *     "filterType": "numeric",
 *     "attribute": { ... },
 *     "valueA": 10,
 *     "valueB": 27249.89453125
 *   }
 * }
 * ```
 *
 * These filters:
 * - Represent calculation constraints that are intrinsic to the clicked widget's datapoint
 * - Are extracted from all dataOption fields of the clicked widget (value, category, breakBy, x, y, etc.)
 * - Support both object format and string reference format
 *
 * ## Duplicate Filter Handling
 *
 * Complex formulas like `AVG(cost) - AVG(PREVMONTH(cost))` can contain multiple filters on the same dimension.
 * The `sendFormulaFiltersDuplicate` parameter controls how duplicates are handled:
 *
 * - **"none"**: Exclude all duplicate filters (only include filters that appear once)
 * - **Number (1+)**: Include only the filter at that position (1-indexed). Invalid numbers treated as "none"
 * - **Other values**: Include only the first duplicate filter
 *
 * Examples:
 * - Formula has 2 filters on Commerce.Cost dimension
 * - `sendFormulaFiltersDuplicate = "none"` → No Cost filters included
 * - `sendFormulaFiltersDuplicate = 1` → Include first Cost filter
 * - `sendFormulaFiltersDuplicate = 2` → Include second Cost filter
 * - `sendFormulaFiltersDuplicate = 3` → Invalid (out of range), treat as "none"
 */
export declare const getFormulaContextFilters: (point: DataPoint, clickedWidget: WidgetProps, jtdConfig: JTDConfig) => Filter[];
/**
 * @internal
 * Handle duplicate formula filters based on sendFormulaFiltersDuplicate parameter
 * @param filters - The filters to handle
 * @param sendFormulaFiltersDuplicate - The send formula filters duplicate parameter
 * @returns The filtered filters
 */
export declare const handleFormulaDuplicateFilters: (filters: Filter[], sendFormulaFiltersDuplicate?: number | 'none') => Filter[];
export declare const getFiltersFromDataPoint: (point: DataPoint) => Filter[];
/**
 * Filter filters based on allowed dimension names, supporting cascading filters
 *
 * @param filters - The filters to filter
 * @param allowedDims - The allowed dimensions
 * @returns The filtered filters
 */
export declare const filterByAllowedDimensions: (filters: Filter[], allowedDims?: string[]) => Filter[];
/**
 * @internal
 * Get the JTD click handler for a specific data point of the specific widget
 * @param jtdConfig - The JTD config
 * @param drillTarget - The drill target
 * @param widgetProps - The widget props
 * @param point - The data point
 * @param dashboardFilters - The dashboard filters
 * @param originalWidgetFilters - The original widget filters
 * @param openModal - The open modal function
 * @returns The JTD click handler
 */
export declare const getJtdClickHandler: (jtdConfig: JTDConfig, drillTarget: JTDDrillTarget, widgetProps: WidgetProps, point: DataPoint, dashboardFilters: Filter[], originalWidgetFilters: Filter[], openModal: (options: {
    title: string;
    width?: number;
    height?: number;
    measurement?: SizeMeasurement;
    allowResize?: boolean;
    content: React.ReactNode;
}) => Promise<string>) => () => Promise<void>;
/**
 * @internal
 * Jump to Dashboard (JTD) hook.
 * Implements the JTD functionality for each widget with JTD config.
 * @param widgetOptions - The widget options of the dashboard
 * @param dashboardFilters - The dashboard filters to use
 * @param widgetFilters - The widget filters to use
 * @param openMenu - The open menu function to use
 * @returns The connect to widget props function
 */
export declare const useJtd: ({ widgetOptions, dashboardFilters, widgetFilters, openMenu, }: {
    widgetOptions: WidgetsOptions;
    dashboardFilters?: Filter[] | undefined;
    widgetFilters?: Map<string, Filter[]> | undefined;
    openMenu: OpenMenuFn;
}) => {
    connectToWidgetProps: (widgetProps: WidgetProps) => WidgetProps;
};
